pub fn read_leases(lease_file: &Path, leases_json: &Path) -> Vec<LeaseEntry>Expand description
Read leases from a dnsmasq lease file, falling back to a JSON export path.
pub fn read_leases(lease_file: &Path, leases_json: &Path) -> Vec<LeaseEntry>Read leases from a dnsmasq lease file, falling back to a JSON export path.